@@ -1,6 +1,7 @@
 from enum import Enum
 from pathlib import Path
-from typing import Dict, Optional
+from typing import TYPE_CHECKING, Any, Dict, Optional
+from warnings import warn
 
 import black
 import isort
@@ -31,7 +32,10 @@ def is_supported_in_black(python_version: PythonVersion) -> bool:  # pragma: no
 
 class CodeFormatter:
     def __init__(
-        self, python_version: PythonVersion, settings_path: Optional[Path] = None
+        self,
+        python_version: PythonVersion,
+        settings_path: Optional[Path] = None,
+        wrap_string_literal: Optional[bool] = None,
     ):
         if not settings_path:
             settings_path = Path().resolve()
@@ -44,11 +48,35 @@ class CodeFormatter:
             config = pyproject_toml.get("tool", {}).get("black", {})
         else:
             config = {}
-        self.back_mode = black.FileMode(
-            target_versions={BLACK_PYTHON_VERSION[python_version]},
-            line_length=config.get("line-length", black.DEFAULT_LINE_LENGTH),
-            string_normalization=not config.get("skip-string-normalization", True),
-        )
+
+        black_kwargs: Dict[str, Any] = {}
+        if wrap_string_literal is not None:
+            experimental_string_processing = wrap_string_literal
+        else:
+            experimental_string_processing = config.get(
+                'experimental-string-processing'
+            )
+
+        if experimental_string_processing is not None:  # pragma: no cover
+            if black.__version__.startswith('19.'):  # type: ignore
+                warn(
+                    f'black doesn\'t support `experimental-string-processing` option'  # type: ignore
+                    f' for wrapping string literal in {black.__version__}'
+                )
+            else:
+                black_kwargs[
+                    'experimental_string_processing'
+                ] = experimental_string_processing
+
+        if TYPE_CHECKING:
+            self.back_mode: black.FileMode
+        else:
+            self.back_mode = black.FileMode(
+                target_versions={BLACK_PYTHON_VERSION[python_version]},
+                line_length=config.get("line-length", black.DEFAULT_LINE_LENGTH),
+                string_normalization=not config.get("skip-string-normalization", True),
+                **black_kwargs,
+            )
 
         self.settings_path: str = str(settings_path)
         if isort.__version__.startswith('4.'):
@@ -56,13 +84,19 @@ class CodeFormatter:
         else:
             self.isort_config = isort.Config(settings_path=self.settings_path)
 
-    def format_code(self, code: str,) -> str:
+    def format_code(
+        self,
+        code: str,
+    ) -> str:
         code = self.apply_isort(code)
         code = self.apply_black(code)
         return code
 
     def apply_black(self, code: str) -> str:
-        return black.format_str(code, mode=self.back_mode,)
+        return black.format_str(
+            code,
+            mode=self.back_mode,
+        )
 
     if isort.__version__.startswith('4.'):
 
