@@ -79,6 +79,7 @@ class DataType(_BaseModel):  # type: ignore
     parent: Optional[Any] = None
     children: List[Any] = []
     strict: bool = False
+    dict_key: Optional['DataType'] = None
 
     _exclude_fields: ClassVar[Set[str]] = {'parent', 'children'}
     _pass_fields: ClassVar[Set[str]] = {'parent', 'children', 'data_types', 'reference'}
@@ -197,6 +198,9 @@ class DataType(_BaseModel):  # type: ignore
             if field and import_ != self.import_:
                 yield import_
 
+        if self.dict_key:
+            yield from self.dict_key.imports
+
     def __init__(self, **values: Any) -> None:
         super().__init__(**values)
 
@@ -214,7 +218,7 @@ class DataType(_BaseModel):  # type: ignore
                 break
 
         for data_type in self.data_types:
-            if data_type.reference:
+            if data_type.reference or data_type.data_types:
                 data_type.parent = self
 
         if self.reference:
@@ -256,7 +260,11 @@ class DataType(_BaseModel):  # type: ignore
                 dict_ = 'dict'
             else:
                 dict_ = 'Dict'
-            type_ = f'{dict_}[str, {type_}]' if type_ else dict_
+            if self.dict_key or type_:
+                key = self.dict_key.type_hint if self.dict_key else 'str'
+                type_ = f'{dict_}[{key}, {type_ or "Any"}]'
+            else:  # pragma: no cover
+                type_ = dict_
         if self.is_optional and type_ != 'Any':
             type_ = f'Optional[{type_}]'
         elif self.is_func:
